/// <reference types="node" />
import JSZip from 'jszip';
import { ArchiveIndex, PartialTweetGDPR, PartialTweet, PartialTweetUser } from './TwitterTypes';
import DMArchive from './DMArchive';
export declare function dateFromTweet(tweet: PartialTweet): Date;
export declare function isWithMedia(tweet: PartialTweet): boolean;
export declare function isWithVideo(tweet: PartialTweet): boolean;
export declare type AcceptedZipSources = string | number[] | Uint8Array | ArrayBuffer | Blob | NodeJS.ReadableStream | JSZip;
declare class Archive {
    protected _ready: Promise<void>;
    protected archive: JSZip;
    constructor(file: AcceptedZipSources);
    ready(): Promise<void>;
    dir(name: string): Archive;
    has(name: string): boolean;
    get(name: string, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    search(query: RegExp): JSZip.JSZipObject[];
    searchDir(query: RegExp): JSZip.JSZipObject[];
    read(file: JSZip.JSZipObject, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    ls(current_dir_only?: boolean): {
        [key: string]: JSZip.JSZipObject;
    };
}
export declare class TwitterArchive {
    protected _ready: Promise<void>;
    protected archive: Archive;
    protected _index: ArchiveIndex;
    protected dms: DMArchive;
    protected _is_gdpr: boolean;
    protected user_cache: PartialTweetUser;
    constructor(file: AcceptedZipSources);
    protected initGDPR(): Promise<void>;
    protected convertToPartial(tweet: PartialTweetGDPR, pic_prof: string): PartialTweet;
    protected initClassic(): Promise<void>;
    protected isGDPRArchive(): boolean;
    isGDPRTweet(tweet: PartialTweetGDPR): true;
    isGDPRTweet(tweet: PartialTweet): false;
    month(month: string, year: string): PartialTweet[];
    between(since: Date, until: Date): PartialTweet[];
    id(id_str: string): PartialTweet | null;
    readonly all: PartialTweet[];
    /** Access to the DMArchive */
    readonly messages: DMArchive;
    /** ID of the user who created this archive */
    readonly owner: string;
    /**
     * Screen name (@) of the user who created this archive.
     * May be obsolete (user can change screen_name over time).
     */
    readonly owner_screen_name: string;
    /** Not accurate in GDPR archive (will be the current date) */
    readonly generation_date: Date;
    readonly index: ArchiveIndex;
    readonly length: number;
    readonly is_gdpr: boolean;
    ready(): Promise<void>;
}
export {};
